@@ -13,6 +13,7 @@
 from dataclasses import dataclass
 import typing_extensions
 import urllib3
+from snaptrade_client.request_before_hook import request_before_hook
 import json
 from urllib3._collections import HTTPHeaderDict
 
@@ -31,9 +32,9 @@ import frozendict  # noqa: F401
 
 from snaptrade_client import schemas  # noqa: F401
 
-from snaptrade_client.model.options_holdings import OptionsHoldings as OptionsHoldingsSchema
+from snaptrade_client.model.options_position import OptionsPosition as OptionsPositionSchema
 
-from snaptrade_client.type.options_holdings import OptionsHoldings
+from snaptrade_client.type.options_position import OptionsPosition
 
 from . import path
 
@@ -104,17 +105,42 @@ _auth = [
     'PartnerSignature',
     'PartnerTimestamp',
 ]
-SchemaFor200ResponseBodyApplicationJson = OptionsHoldingsSchema
+
+
+class SchemaFor200ResponseBodyApplicationJson(
+    schemas.ListSchema
+):
+
+
+    class MetaOapg:
+        
+        @staticmethod
+        def items() -> typing.Type['OptionsPositionSchema']:
+            return OptionsPositionSchema
+
+    def __new__(
+        cls,
+        arg: typing.Union[typing.Tuple['OptionsPosition'], typing.List['OptionsPosition']],
+        _configuration: typing.Optional[schemas.Configuration] = None,
+    ) -> 'SchemaFor200ResponseBodyApplicationJson':
+        return super().__new__(
+            cls,
+            arg,
+            _configuration=_configuration,
+        )
+
+    def __getitem__(self, i: int) -> 'OptionsPosition':
+        return super().__getitem__(i)
 
 
 @dataclass
 class ApiResponseFor200(api_client.ApiResponse):
-    body: OptionsHoldings
+    body: typing.List[OptionsPosition]
 
 
 @dataclass
 class ApiResponseFor200Async(api_client.AsyncApiResponse):
-    body: OptionsHoldings
+    body: typing.List[OptionsPosition]
 
 
 _response_for_200 = api_client.OpenApiResponse(
@@ -228,17 +254,33 @@ class BaseApi(api_client.Api):
         if accept_content_types:
             for accept_content_type in accept_content_types:
                 _headers.add('Accept', accept_content_type)
+        method = 'get'.upper()
+        request_before_hook(
+            resource_path=used_path,
+            method=method,
+            configuration=self.api_client.configuration,
+            auth_settings=_auth,
+            headers=_headers,
+        )
     
         response = await self.api_client.async_call_api(
             resource_path=used_path,
-            method='get'.upper(),
+            method=method,
             headers=_headers,
             auth_settings=_auth,
             prefix_separator_iterator=prefix_separator_iterator,
             timeout=timeout,
         )
-        
+    
         if stream:
+            if not 200 <= response.http_response.status <= 299:
+                body = (await response.http_response.content.read()).decode("utf-8")
+                raise exceptions.ApiStreamingException(
+                    status=response.http_response.status,
+                    reason=response.http_response.reason,
+                    body=body,
+                )
+    
             async def stream_iterator():
                 """
                 iterates over response.http_response.content and closes connection once iteration has finished
@@ -283,6 +325,7 @@ class BaseApi(api_client.Api):
     
         return api_response
 
+
     def _list_option_holdings_oapg(
         self,
         query_params: typing.Optional[dict] = {},
@@ -337,10 +380,18 @@ class BaseApi(api_client.Api):
         if accept_content_types:
             for accept_content_type in accept_content_types:
                 _headers.add('Accept', accept_content_type)
+        method = 'get'.upper()
+        request_before_hook(
+            resource_path=used_path,
+            method=method,
+            configuration=self.api_client.configuration,
+            auth_settings=_auth,
+            headers=_headers,
+        )
     
         response = self.api_client.call_api(
             resource_path=used_path,
-            method='get'.upper(),
+            method=method,
             headers=_headers,
             auth_settings=_auth,
             prefix_separator_iterator=prefix_separator_iterator,
@@ -370,6 +421,7 @@ class BaseApi(api_client.Api):
     
         return api_response
 
+
 class ListOptionHoldings(BaseApi):
     # this class is used by api classes that refer to endpoints with operationId fn names
 
